<?php
/**
 * Plugin Name: Tomato Boldify Text Plugin
 * Plugin URI: tomatoboldifytextplugin.netlify.app
 * Description: Highlight and emphasize text with ease. Tomato Boldify Text Plugin allows you to quickly write key words or text and make them stand out using bold formatting.
 * Version: 1.0
 * Author: Ricky Ricardo
 * Author URI: https://github.com/ricardo-719
 * Text Domain: boldify-text-plugin
*/

// Set up global variable for localization
$saved_text_global = get_option('boldify_text');;

// Register the admin menu page
function boldify_text_plugin_menu() {
  add_menu_page(
    'Boldify Text Plugin',
    'Boldify Text',
    'manage_options',
    'boldify-text-plugin',
    'boldify_text_plugin_page'
  );
}
add_action('admin_menu', 'boldify_text_plugin_menu');

// Callback function for the admin menu page
function boldify_text_plugin_page() {

  // Retrieve the saved input value
  $saved_text = get_option('boldify_text');

  // Check if the form is submitted
  if (isset($_POST['boldify_text_submit'])) {
    // Save the submitted value
    $saved_text = sanitize_text_field($_POST['boldify_text']);
    update_option('boldify_text', $saved_text);
  }

  ?>
  <div class="wrap">
    <h1>Boldify Text Plugin</h1>
    <form method="POST" action="">
      <?php settings_fields('boldify-text-plugin'); ?>
      <label for="boldify_text">Text:</label>
      <input type="text" id="boldify_text" name="boldify_text" value="<?php echo esc_attr($saved_text); ?>">
      <p class="description">Enter the text to be saved and highlighted.</p>
      <input type="submit" name="boldify_text_submit" class="button-primary" value="Save">
    </form>
  </div>
  <?php
}
  
// Enqueue the JavaScript file
function boldify_text_plugin_enqueue_scripts() {

  global $saved_text_global;
  wp_enqueue_script(
    'boldify-text-script',
    plugin_dir_url(__FILE__) . 'assets/boldify-text.js',
    array('jquery'),
    '1.0.0',
    true
  );
  wp_localize_script('boldify-text-script', 'saved_text', $saved_text_global);
}
add_action('wp_enqueue_scripts', 'boldify_text_plugin_enqueue_scripts');
  
// Plugin activation hook
function boldify_text_plugin_activate() {
  // Set default value on activation
  add_option('boldify_text', '');
}
register_activation_hook(__FILE__, 'boldify_text_plugin_activate');
  
// Plugin deactivation hook
function boldify_text_plugin_deactivate() {
  // Clean up any data on deactivation
  delete_option('boldify_text');
}
register_deactivation_hook(__FILE__, 'boldify_text_plugin_deactivate');